Release 0.0.3 (calculatorpython):
    -Change in setup.py file

This package is calculatorpython. You can import it by saying for example
'from calculatorpython import add'
Hope you like this release of calculatorpython.
Thanks,
Advait,
Author,
calculatorpython
